from distutils.core import setup

setup(
    name='xenon_tools',
    packages=['xenon_tools'],  # this must be the same as the name above
    version='0.1.3',
    description='Tools for Xenon',
    author='minus79',
    author_email='gergely06@gmail.com',
    url='https://github.com/minus79/xenon_tools',  # use the URL to the github repo
    download_url='https://github.com/minus79/xenon_tools/tarball/0.1',  # I'll explain this in a second
    keywords=['xenon', 'xenon-tools', 'xenon_tools'],  # arbitrary keywords
    classifiers=[],
)



#! /usr/bin/env python
import sys


def human_time(seconds):
    if not seconds:
        seconds = 0
    m, s = divmod(seconds, 60)
    h, m = divmod(m, 60)
    return "%02d:%02d" % (m, s) if h == 0 else "%d:%02d:%02d" % (h, m, s)


def push_in_range(val, minimum, maximum):
    if val < minimum:
        return minimum
    elif val > maximum:
        return maximum
    else:
        return val


def print_progress(iteration, total, time=0, mdet=None, prefix='', suffix='', decimals=1, bar_length=100):
    format_str = "{0:." + str(decimals) + "f}"
    percents = format_str.format(100 * (iteration / float(total)))
    filled_length = int(round(bar_length * iteration / float(total)))
    bar = '=' * filled_length + ' ' * (bar_length - filled_length)
    if mdet is None:
        sys.stdout.write('\r%s |%s| %s%s %s' % (prefix, bar, percents, '%', suffix))
    else:
        sys.stdout.write('\r%s |%s| %s%s %s %s=%s-%s [%shz][%sch][%sbytes/sample]' %
                         (prefix, bar, percents, '%', suffix,
                          human_time(time), human_time(mdet.duration_seconds), human_time(mdet.duration_seconds - time),
                          mdet.frame_rate, mdet.no_channels, mdet.frame_width))
    sys.stdout.flush()
    if iteration == total:
        sys.stdout.write('\n')
        sys.stdout.flush()


class MediaDetails:
    duration_seconds = 0
    duration_human = ''
    frame_rate = 0
    no_channels = 0
    frame_width = 0

    def __init__(self, duration_seconds=0, frame_rate=0, no_channels=0, frame_width=0):
        self.duration_seconds = duration_seconds
        self.duration_human = human_time(duration_seconds)
        self.frame_width = frame_width
        self.frame_rate = frame_rate
        self.no_channels = no_channels



#! /usr/bin/env python
from collections import defaultdict

import sys


class Args:
    obj = None

    d = defaultdict(list)
    synonyms = defaultdict(list)
    callbacks = defaultdict(list)

    def __init__(self, obj):
        self.obj = obj

    def register(self, word, callback, n_args=0, synonyms=[]):
        if not self.d[word]:
            self.d[word] = [callback, n_args]
            self.synonyms[word] = synonyms

    def act(self, args):
        l = len(args)
        i = 0
        while i < l:
            a = self.resolve_word(args[i])
            if a in self.d:
                callback = self.d[a][0]
                n = self.d[a][1]
                callargs = []
                for j in range(n):
                    callargs.append(args[i + j + 1])
                i += n + 1
                self.callbacks[callback] = callargs
                callback(*callargs)
            else:
                print 'Unknown argument', a
                i += 1

    def resolve_word(self, word):
        if word in self.d:
            return word
        else:
            for key in self.synonyms:
                if word in self.synonyms[key]:
                    return key
        return None


if __name__ == "__main__":
    class testclass:
        def playfrom(self, n):
            print 'playing from', n

        def shuffle(self):
            print 'shuffling'


    tc = testclass()

    args = Args(tc)
    args.register('from', tc.playfrom, 1, ['playfrom', 'fr'])
    args.register('shuf', tc.shuffle, 0, ['shuff', 'shuffle'])

    print args.synonyms
    args.act(sys.argv[1:])
